@@ -1,5 +1,5 @@
 """This is part of the MSS Python's module.
-Source: https://github.com/BoboTiG/python-mss.
+Source: https://github.com/BoboTiG/python-..mss.
 """
 from __future__ import annotations
 
@@ -29,12 +29,12 @@ from ctypes.util import find_library
 from threading import current_thread, local
 from typing import TYPE_CHECKING, Any, Tuple
 
-from mss.base import MSSBase, lock
-from mss.exception import ScreenShotError
+from ..mss.base import MSSBase, lock
+from ..mss.exception import ScreenShotError
 
 if TYPE_CHECKING:
-    from mss.models import CFunctions, Monitor
-    from mss.screenshot import ScreenShot
+    from ..mss.models import CFunctions, Monitor
+    from ..mss.screenshot import ScreenShot
 
 __all__ = ("MSS",)
 
